@@ -1,5 +1,5 @@
 from types import MethodType
-from typing import Any, Callable, List, Optional, Tuple, Set, cast
+from typing import Any, Callable, List, Optional, Set, Tuple, cast
 
 from .types import DriverAdapterProtocol, QueryDatum, QueryDataTree, QueryFn, SQLOperationType
 
@@ -96,6 +96,10 @@ def _create_methods(query_datum: QueryDatum, is_aio: bool) -> List[Tuple[str, Qu
 
     ctx_mgr = _make_ctx_mgr(fn)
 
+    # TODO: 4.0.0 release
+    # The return can and should be simplified to List[QueryFn]
+    # i.e.
+    # return [fn, ctx_mgr] and [fn]
     if query_datum.operation_type == SQLOperationType.SELECT:
         return [(fn.__name__, fn), (ctx_mgr.__name__, ctx_mgr)]
     else:
@@ -145,6 +149,10 @@ class Queries:
     def add_queries(self, queries: List[Tuple[str, QueryFn]]):
         """Add query methods to `Queries` instance."""
         for query_name, fn in queries:
+            # TODO: Could be query_name = fn.__name__.rpartition(".")[2]
+            # if the interface here were changed to just queries being
+            # a List[QueryFn]
+            query_name = query_name.rpartition(".")[2]
             self.add_query(query_name, MethodType(fn, self))
 
     def add_child_queries(self, child_name: str, child_queries: "Queries"):
