@@ -15,8 +15,7 @@ from typing_extensions import Protocol
 
 
 class SQLOperationType(Enum):
-    """Enumeration of aiosql operation types.
-    """
+    """Enumeration of aiosql operation types."""
 
     INSERT_RETURNING = 0
     INSERT_UPDATE_DELETE = 1
@@ -24,6 +23,7 @@ class SQLOperationType(Enum):
     SCRIPT = 3
     SELECT = 4
     SELECT_ONE = 5
+    SELECT_VALUE = 6
 
 
 class QueryDatum(NamedTuple):
@@ -34,6 +34,15 @@ class QueryDatum(NamedTuple):
     record_class: Any = None
 
 
+class QueryFn(Protocol):
+    __name__: str
+    sql: str
+    operation: SQLOperationType
+
+    def __call__(self, *args: Any, **kwargs: Any) -> Any:
+        ...
+
+
 # Can't make this a recursive type in terms of itself
 # QueryDataTree = Dict[str, Union[QueryDatum, 'QueryDataTree']]
 QueryDataTree = Dict[str, Union[QueryDatum, Dict]]
@@ -63,6 +72,11 @@ class SyncDriverAdapterProtocol(Protocol):
     ) -> Optional[Any]:
         ...
 
+    def select_value(
+        self, conn: Any, query_name: str, sql: str, parameters: Union[List, Dict]
+    ) -> Optional[Any]:
+        ...
+
     def select_cursor(
         self, conn: Any, query_name: str, sql: str, parameters: Union[List, Dict]
     ) -> ContextManager[Any]:
@@ -85,8 +99,7 @@ class SyncDriverAdapterProtocol(Protocol):
     ) -> Optional[Any]:
         ...
 
-    # TODO: Next major version introduce a return? Optional return?
-    def execute_script(self, conn: Any, sql: str) -> None:
+    def execute_script(self, conn: Any, sql: str) -> str:
         ...
 
 
@@ -114,6 +127,11 @@ class AsyncDriverAdapterProtocol(Protocol):
     ) -> Optional[Any]:
         ...
 
+    async def select_value(
+        self, conn: Any, query_name: str, sql: str, parameters: Union[List, Dict]
+    ) -> Optional[Any]:
+        ...
+
     async def select_cursor(
         self, conn: Any, query_name: str, sql: str, parameters: Union[List, Dict]
     ) -> AsyncContextManager[Any]:
@@ -136,8 +154,7 @@ class AsyncDriverAdapterProtocol(Protocol):
     ) -> Optional[Any]:
         ...
 
-    # TODO: Next major version introduce a return? Optional return?
-    async def execute_script(self, conn: Any, sql: str) -> None:
+    async def execute_script(self, conn: Any, sql: str) -> str:
         ...
 
 
